# Changelog

## [0.5.2](https://github.com/cognitedata/cognite-typed-functions/compare/cognite-typed-functions-v0.5.1...cognite-typed-functions-v0.5.2) (2025-11-20)


### Bug Fixes

* update publish workflow to trigger on merge commits ([84c30c7](https://github.com/cognitedata/cognite-typed-functions/commit/84c30c7393e70e9b035732a573317bb0ed1d80f0))

## [0.5.1](https://github.com/cognitedata/cognite-typed-functions/compare/cognite-typed-functions-v0.5.0...cognite-typed-functions-v0.5.1) (2025-11-20)


### Bug Fixes

* update version to 0.5.0 and configure release-please annotations ([3a01001](https://github.com/cognitedata/cognite-typed-functions/commit/3a0100101738d008957075fa73523fb2db5558c6))

## [0.5.0](https://github.com/cognitedata/cognite-typed-functions/compare/cognite-typed-functions-v0.4.0...cognite-typed-functions-v0.5.0) (2025-11-19)


### Features

* add automatic trace propagation via traceparent header ([f410e2f](https://github.com/cognitedata/cognite-typed-functions/commit/f410e2fb75587cfba30c048f083f0dd6a806a87b))

## [0.4.0](https://github.com/cognitedata/cognite-typed-functions/compare/cognite-typed-functions-v0.3.2...cognite-typed-functions-v0.4.0) (2025-11-19)


### ⚠ BREAKING CHANGES

* Streamlines tracing setup to one line before v1.0. Taking this opportunity to fix the API while adoption is still early.

### Features

* Add exporter_provider to TracingApp for secret-based authentication ([dabbe4f](https://github.com/cognitedata/cognite-typed-functions/commit/dabbe4f22ef595f9e397c0b8a403526e03812f3e))
* make the docs actionable as a tutorial, and smaller. ([6377121](https://github.com/cognitedata/cognite-typed-functions/commit/6377121866b6d4dfb92f9748be0fb33477c87e0d))
* reduce docs for tracer ([aa27a59](https://github.com/cognitedata/cognite-typed-functions/commit/aa27a5962d7fee0bf48f8a96423a24ad999354c6))
* simplify tracing API with backend presets ([0ecb671](https://github.com/cognitedata/cognite-typed-functions/commit/0ecb671327e87992ef6baa77b10f8f90fa694a6e))
* standardize secret key with actionable error messages ([63a0641](https://github.com/cognitedata/cognite-typed-functions/commit/63a0641e015986bfcce0976124598b0097267501))


### Bug Fixes

* configure release-please to use manifest mode ([45623b2](https://github.com/cognitedata/cognite-typed-functions/commit/45623b2d39c075c703d8a09d8741120ec21607b5))
* update release-please workflow to use PAT token ([ea6cc26](https://github.com/cognitedata/cognite-typed-functions/commit/ea6cc26bf9c827917a9b974dc44721b4f8995455))
* use version-file instead of extra-files for Python version ([5122824](https://github.com/cognitedata/cognite-typed-functions/commit/51228249b214b74a5cfda5f9e445a000be86f234))


### Code Refactoring

* address PR review comments ([30a94e9](https://github.com/cognitedata/cognite-typed-functions/commit/30a94e903fa269e16c38849b30d6c77ad9df8d8b))
* consolidate tracing to single exporter path ([8ee34dc](https://github.com/cognitedata/cognite-typed-functions/commit/8ee34dcbb73cea2ab692f4f633fcae3e8dcba550))
* use version-file instead of extra-files ([2f49ca5](https://github.com/cognitedata/cognite-typed-functions/commit/2f49ca5934758088141102aeebcaa2bd4f781512))
